---
title: Overview
page_title: Chart Overview - Components - Kendo UI for Vue
description: "Get an overview of the features the Kendo UI Chart wrapper for Vue delivers and use the component in Vue projects."
slug: overview_chart_charts
position: 1
---

# Chart Overview

The Chart renders a wide range of high-quality data visualizations.

The Chart wrapper for Vue is a client-side wrapper for the [Kendo UI Chart]({% slug api_chartcomponent %}) widget.

## Basic Usage

The following example demonstrates the Chart in action.

{% meta height:460  %}
```html-preview
<div id="vueapp" class="vue-app">
    <kendo-chart :title-text="'Kendo Chart Example'"
                 :legend-position="'bottom'"
                 :series="series"
                 :category-axis-categories="categories"
                 :value-axis="axis"
                 :theme="'sass'">
    </kendo-chart>
</div>
```
```js
Vue.use(ChartInstaller);

new Vue({
    el: "#vueapp",
    data: function() {
        return {
            series: [{
                name: 'Temperature',
                data: [20, 25, 32],
                axis: "temperature"
            },
            {
                name: 'Humidity',
                data: [40, 50, 80],
                axis: "humidity"
            }],
            categories: ["Aug", "Sep", "Oct"],
            axis: [{
                name: "temperature",
                labels: {
                    format: "{0}C"
                }
            },
            {
                name: "humidity",
                labels: {
                    format: "{0}%"
                }
            }]
        }
    }
})
```
{% endmeta %}

## Functionality and Features

* [Data binding]({% slug databinding_chart_charts %})
* [Panning and zooming]({% slug pan_and_zoom_chart_charts %})
* Elements
    * [Axes]({% slug axes_chart_charts %})
    * [Error bars]({% slug error_bars_chart_charts %})
    * [Plot bands]({% slug plot_bands_chart_charts %})

## Events

The following example demonstrates basic Chart events. You can subscribe to [all Chart events]({% slug api_chartcomponent %}#events) by the handler name.

```html
<div id="vueapp" class="vue-app">
    <kendo-chart :title-text="'Kendo Chart Example'"
                 :legend-position="'bottom'"
                 :series="series"
                 :category-axis-categories="categories"
                 :value-axis="axis"
                 :theme="'sass'"
                 @axislabelclick="onAxisLabelClick">
    </kendo-chart>
</div>
```
```js
Vue.use(ChartInstaller);

new Vue({
    el: "#vueapp",
    data: function() {
        return {
            series: [{
                name: 'Temperature',
                data: [20, 25, 32],
                axis: "temperature"
            },
            {
                name: 'Humidity',
                data: [40, 50, 80],
                axis: "humidity"
            }],
            categories: ["Aug", "Sep", "Oct"],
            axis: [{
                name: "temperature",
                labels: {
                    format: "{0}C"
                }
            },
            {
                name: "humidity",
                labels: {
                    format: "{0}%"
                }
            }]
        }
    },
    methods: {
        onAxisLabelClick: function(e) {
            console.log("Event :: axisLabelClick");
        }
    }
})
```

## Suggested Links

* [Kendo UI Chart for jQuery](https://docs.telerik.com/kendo-ui/controls/charts/overview)
* [API Reference of the Chart Widget](https://docs.telerik.com/kendo-ui/api/javascript/dataviz/ui/chart)
