---
title: Overview
page_title: StockChart Overview - Components - Kendo UI for Vue
description: "Get an overview of the features the Kendo UI StockChart wrapper for Vue delivers and use the component in Vue projects."
slug: overview_stockchart_charts
position: 0
---

# StockChart Overview

The StockChart is a specialized control for visualizing the price movement of a financial instrument over a certain period of time.

StockCharts include extensive touch support and a navigator pane for easy browsing of extended time periods. Generally, the StockChart extends the [Kendo UI Chart]({% slug overview_chart_charts %}) and shares most of its features.

The StockChart wrapper for Vue is a client-side wrapper for the [Kendo UI StockChart]({% slug api_stockchartcomponent %}) widget.

## Basic Usage

The following example demonstrates the StockChart in action.

{% meta height:460 %}
```html-preview
<div id="vueapp" class="vue-app">
    <kendo-datasource :ref="'datasource'"
                      :transport-read-data-type="'jsonp'"
                      :transport-read-url="'https://demos.telerik.com/kendo-ui/service/StockData'"
                      :schema-model-fields="fields">
    </kendo-datasource>
    <kendo-stockchart :data-source-ref="'datasource'"
                      :date-field="'Date'"
                      :title-text="'The Boeing Company\nNYSE:BA'"
                      :category-axis-labels-rotation="'auto'"
                      :navigator-series="navigatorSeries"
                      :navigator-select-from="'2009/02/05'"
                      :navigator-select-to="'2011/10/07'"
                      :navigator-category-axis-labels-rotation="'auto'"
                      :theme="'sass'">
        <kendo-chart-series-item :type="'candlestick'"
                                 :open-field="'Open'"
                                 :high-field="'High'"
                                 :low-field="'Low'"
                                 :close-field="'Close'">
        </kendo-chart-series-item>
    </kendo-stockchart>
</div>
```
```js
Vue.use(ChartInstaller);
Vue.use(DataSourceInstaller);

new Vue({
    el: "#vueapp",
    data: function() {
        return {
            fields: {
                Date: { type: 'date' }
            },
            navigatorSeries: {
                type: 'area',
                field: 'Close'
            }
        }
    }
})
```
{% endmeta %}

## Functionality and Features

The StockChart delivers the navigator&mdash;a pane which is placed at the bottom of the StockChart and can be used to change the date interval that is shown in the main panes. To configure the navigator, use the `navigator` option.

> In addition to its individual Navigator feature, the StockChart supports all configuration options of the Chart.

## Suggested Links

* [Kendo UI StockChart for jQuery]({% slug overview_charts %})
* [API Reference of the StockChart Widget](https://docs.telerik.com/kendo-ui/api/javascript/dataviz/ui/stock-chart)
